@@ -28,11 +28,11 @@ namespace Palapeli
     public:
         CollectionDelegate     (QObject* parent = 0);
 
-        virtual void paint     (QPainter* painter,
+        void paint     (QPainter* painter,
                                 const QStyleOptionViewItem& option,
-                                const QModelIndex& index) const;
-        virtual QSize sizeHint (const QStyleOptionViewItem& option,
-                                const QModelIndex& index) const;
+                                const QModelIndex& index) const Q_DECL_OVERRIDE;
+        QSize sizeHint (const QStyleOptionViewItem& option,
+                                const QModelIndex& index) const Q_DECL_OVERRIDE;
 
     private:
         QRect thumbnailRect    (const QRect& baseRect) const;
